@@ -406,21 +406,29 @@ class DataPlate:
             if 'df' in kwargs:
                 # df = pd.read_json(args['df'])
                 kwargs['df'] = kwargs['df'].to_json()
-                # json_kwargs_object = json.dumps(kwargs)
+                json_kwargs_object = json.dumps(kwargs)
                 if len(kwargs['df']) <= 5:
                     logging.error('Empty dataframe !')
                     return
-            # else:
-            return wr.s3.to_csv(*sba.args, **sba.kwargs)
+            elif len(args) >= 1:
+                try:
+                    kwargs['df'] = args[0].to_json()
+                    json_kwargs_object = json.dumps(kwargs)
+                except Exception as e:
+                    logging.error('Empty dataframe !')
+                    return
+            else:
+                logging.error('Empty dataframe !')
+                # return wr.s3.to_csv(*sba.args, **sba.kwargs)
 
 
             headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
-            params = json.dumps(args)#{}
+            # params = json.dumps(args)#{}
 
             try:
                 logging.info('Uploading data...')
                 r = self.session.post( \
-                    '{}/api/aws/toS3_csv'.format(self.base_url), params=params, data=json_kwargs_object,
+                    '{}/api/aws/toS3_csv'.format(self.base_url), data=json_kwargs_object,
                     headers=headers, stream=True, allow_redirects=False)
 
                 if r.status_code != 200:
@@ -471,21 +479,29 @@ class DataPlate:
             if 'df' in kwargs:
                 # df = pd.read_json(args['df'])
                 kwargs['df'] = kwargs['df'].to_json()
-                # json_kwargs_object = json.dumps(kwargs)
+                json_kwargs_object = json.dumps(kwargs)
                 if len(kwargs['df']) <= 5:
                     logging.error('Empty dataframe !')
                     return
-            # else:
-            return wr.s3.to_json(*sba.args, **sba.kwargs)
+            elif len(args) >= 1:
+                try:
+                    kwargs['df'] = args[0].to_json()
+                    json_kwargs_object = json.dumps(kwargs)
+                except Exception as e:
+                    logging.error('Empty dataframe !')
+                    return
+            else:
+                logging.error('Empty dataframe !')
+                # return wr.s3.to_json(*sba.args, **sba.kwargs)
 
 
             headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
-            params = json.dumps(args)#{}
+            # params = json.dumps(args)#{}
 
             try:
                 logging.info('Uploading data...')
                 r = self.session.post( \
-                    '{}/api/aws/toS3_json'.format(self.base_url), params=params, data=json_kwargs_object,
+                    '{}/api/aws/toS3_json'.format(self.base_url), data=json_kwargs_object,
                     headers=headers, stream=True, allow_redirects=False)
 
                 if r.status_code != 200:
@@ -536,21 +552,30 @@ class DataPlate:
             if 'df' in kwargs:
                 # df = pd.read_json(args['df'])
                 kwargs['df'] = kwargs['df'].to_json()
-                # json_kwargs_object = json.dumps(kwargs)
+                json_kwargs_object = json.dumps(kwargs)
                 if len(kwargs['df']) <= 5:
                     logging.error('Empty dataframe !')
                     return
-            # else:
-            return wr.s3.to_json(*sba.args, **sba.kwargs)
+            elif len(args) >= 1:
+                try:
+                    kwargs['df'] = args[0].to_json()
+                    json_kwargs_object = json.dumps(kwargs)
+                except Exception as e:
+                    logging.error('Empty dataframe !')
+                    return
+            else:
+                logging.error('Empty dataframe !')
+                # return wr.s3.to_parquet(*sba.args, **sba.kwargs)
 
 
             headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
-            params = json.dumps(args)#{}
+            # params = json.dumps(kwargs)#{}
 
             try:
                 logging.info('Uploading data...')
+                #params=params,
                 r = self.session.post( \
-                    '{}/api/aws/toS3_parquet'.format(self.base_url), params=params, data=json_kwargs_object,
+                    '{}/api/aws/toS3_parquet'.format(self.base_url), data=json_kwargs_object,
                     headers=headers, stream=True, allow_redirects=False)
 
                 if r.status_code != 200:
@@ -1273,6 +1298,78 @@ class DataPlate:
             raise Error(e)
 
 
+    def scan_notebook(self, notebook_file_path, parameters = "{}"):
+        """Scan a notebook Job result for security issue.
+        Args:
+            notebook (str): The notebook file path.
+            input_path (str): The S3 object containing the notebook. If this is None, the `notebook` argument is
+                              taken as a local file to upload (default: None).
+            parameters (dict): The dictionary of parameters to pass to the scanner (default: {}).
+        Returns:
+            Json list of compromised (exceptions, suspicious, dangerous actions)
+        """
+        try:
+            if not notebook_file_path or not os.path.isfile(notebook_file_path) or not notebook_file_path.endswith('.ipynb'):
+                raise FileNotFoundError(f'notebook file is not legal/valid : {notebook_file_path if notebook_file_path else "None"}')
+
+            f = open(notebook_file_path, 'r')
+            if f:
+                # Reading from file
+                notebook_json_data = json.loads(f.read())
+                # Closing file
+                f.close()
+
+            if not notebook_json_data or len(json.dumps(notebook_json_data)) < 10 or not 'cells' in notebook_json_data:
+                raise Error(f'notebook file is not legal : {notebook_file_path if notebook_file_path else "None"}')
+
+            notebook_name = os.path.basename(notebook_file_path)
+            params = {}
+            if parameters:
+                params['parameters'] = parameters
+
+            params['notebook_name'] = notebook_name if notebook_name else ""
+
+            headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
+
+            try:
+                logging.info('Uploading data...')
+                r = self.session.post( \
+                    '{}/api/sec/scanNotebook'.format(self.base_url), params=params, data=json.dumps(notebook_json_data),
+                    headers=headers, stream=True, allow_redirects=False)
+
+                if r.status_code != 200:
+                    if r.status_code == 302:
+                        raise Error(
+                            'Bad Access Key! Get your access key at: {}'.format(
+                                self.base_url))
+                    if r.status_code == 206:
+                        logging.info('scanning notebook, processing...')
+                        time.sleep(5)
+                    raise Error(
+                        'Bad HTTP exit status returned from the API: {}. Error was: {}'.
+                            format(r.status_code, r.text))
+
+                logging.info('Parsing response')
+                # logging.info(str(r.text))
+                if r.text:
+                    rJson = json.loads(r.text)
+                    logging.info('scan notebook finished successfully.')
+                    parsed_json = ast.literal_eval(rJson)
+                    df_compromise = pd.read_json(json.dumps(parsed_json))
+                    return df_compromise#r.text.replace('"','')#json.dumps(rJson)
+                else:
+                    logging.exception('Could not find proper output, please check your parameters')
+                # return r.text
+
+            except (requests.exceptions.ConnectionError,
+                    requests.exceptions.ReadTimeout) as e:
+                logging.exception('Got ConnectionError/ReadTimeout exception.')
+                raise Error(e)
+
+        except Exception as e:
+            logging.exception('scan_notebook , ' + str(e))
+            raise Error(e)
+
 
     def analyzeNotebookResult(self, job_name= None):
         """Analyze the named job.
